Support
=======

If you run into a problem with robotpy-build that you think is a bug, or
perhaps there is something wrong with the documentation or just too
difficult to do, please feel free to file bug reports on the `github issue tracker
<https://github.com/robotpy/robotpy-build/issues>`_.

The developers can also be reached at the `RobotPy Gitter channel
<https://gitter.im/robotpy/robotpy-wpilib>`_. 